@@ -22,9 +22,9 @@ TEN_THOUSAND = 10000
 
 
 def total_mv_classification(real_time_quotes_now):
-    real_time_quotes_now['flow_mv_sp'] = round((real_time_quotes_now['flow_mv'] / HUNDRED_MILLION), 2)
-    real_time_quotes_now['total_mv_sp'] = round((real_time_quotes_now['total_mv'] / HUNDRED_MILLION), 2)
-    real_time_quotes_now['flow_mv_level'] = 0
+    real_time_quotes_now.loc[:, 'flow_mv_sp'] = round((real_time_quotes_now['flow_mv'] / HUNDRED_MILLION), 2)
+    real_time_quotes_now.loc[:, 'total_mv_sp'] = round((real_time_quotes_now['total_mv'] / HUNDRED_MILLION), 2)
+    real_time_quotes_now.loc[:, 'flow_mv_level'] = 0
 
     real_time_quotes_now.reset_index(drop=True, inplace=True)
     real_time_quotes_now.loc[(real_time_quotes_now["flow_mv_sp"] >= 0), ['flow_mv_level']] \
@@ -64,6 +64,11 @@ def exclude_new_stock(real_time_quotes_now_df):
     return real_time_quotes_now_df.loc[~(real_time_quotes_now_df['name'].str.contains('N'))]
 
 
+# 排除 包含名字中包含特定字母的数据
+def exclude_str_name_stock(real_time_quotes_now_df, str_name):
+    return real_time_quotes_now_df.loc[~(real_time_quotes_now_df['name'].str.contains(str_name))]
+
+
 # 排除st
 def exclude_st_symbol(real_time_quotes_now_df):
     exclude_st_symbol_list = list(
@@ -90,6 +95,7 @@ def exclude_b_symbol(real_time_quotes_now_df):
                                        | (real_time_quotes_now_df.symbol.str.startswith('0'))
                                        | (real_time_quotes_now_df.symbol.str.startswith('6'))
                                        | (real_time_quotes_now_df.symbol.str.startswith('4'))
+                                       | (real_time_quotes_now_df.symbol.str.startswith('9'))
                                        | (real_time_quotes_now_df.symbol.str.startswith('8'))]
 
 
@@ -137,3 +143,13 @@ def calculate_index(real_time_quotes_now_df):
 def group_by_industry_sum(real_time_quotes_now, field1, field2):
     df_series = real_time_quotes_now.groupby(by=[field1])[field2].sum()
     return pd.DataFrame({field1: df_series.index, field2: df_series.values})
+
+
+def symbol_add_prefix(symbol):
+    symbol_simple = symbol[0:6]
+    if symbol_simple.startswith('6'):
+        return '1.' + symbol_simple
+    elif symbol_simple.startswith('0') or symbol_simple.startswith('3'):
+        return '0.' + symbol_simple
+    else:
+        return '0.' + symbol_simple
