@@ -61,9 +61,19 @@ def set_ths_concept(symbol, df):
     df['ths_concept_name'] = "未有"
     df['ths_concept_code'] = 0
     df['ths_concept_sync_day'] = "1989-07-29"
+    # 有效数量
+    df['ths_concept_count'] = 0
 
     df['ths_concept_list_info'] = "-"
 
+    df['ths_concept_name_list_str'] = "-"
+
+    df['ths_concept_most_relative_name'] = "未有"
+
+    df['ths_concept_most_relative_code'] = 0
+
+    df['ths_concept_list'] = [[] for _ in range(len(df))]
+
     if ths_stock_concept_detail.shape[0] == 0:
         return df
 
@@ -72,21 +82,38 @@ def set_ths_concept(symbol, df):
     ths_stock_concept_detail.dropna(subset=['concept_code'], axis=0, inplace=True)
 
     if data_frame_util.is_not_empty(ths_stock_concept_detail):
+        ths_stock_concept_detail['concept_name_str'] = ths_stock_concept_detail['concept_name']
+        df_unique = ths_stock_concept_detail['concept_name_str'].drop_duplicates()
+        concept_name_str = ','.join(df_unique)
+
         ths_stock_concept_detail = ths_stock_concept_detail[[
             'concept_code',
             'concept_name',
+            'grade',
+            'remark',
             'str_day',
             'str_now_time',
             'concept_create_day']]
         # 去除空格
         ths_stock_concept_detail['concept_name'] = ths_stock_concept_detail['concept_name'].str.replace(' ', '')
+
         df.loc[:, 'ths_concept_list_info'] = ths_stock_concept_detail.to_string(index=False)
+        df.loc[:, 'ths_concept_name_list_str'] = concept_name_str
+        ths_concept_list_record = ths_stock_concept_detail.to_dict(orient='records')
+        df.at[df.index[0], 'ths_concept_list'] = ths_concept_list_record
 
     ths_effective_concept_list = get_all_ths_effective_concept()
     ths_effective_concept_code_list = list(ths_effective_concept_list['symbol'])
 
     ths_stock_concept_detail_effective = ths_stock_concept_detail.loc[
         ths_stock_concept_detail['concept_code'].isin(ths_effective_concept_code_list)]
+
+    ths_stock_concept_detail_effective = ths_stock_concept_detail_effective.sort_values(by=['concept_code'],
+                                                                                        ascending=False)
+    ths_concept_count = ths_stock_concept_detail_effective.shape[0]
+
+    df.loc[:, 'ths_concept_count'] = ths_concept_count
+
     if data_frame_util.is_empty(ths_stock_concept_detail_effective):
         return df
     # 最新概念设置
@@ -102,6 +129,21 @@ def set_ths_concept(symbol, df):
 
     df['ths_concept_sync_day'] = list(ths_stock_concept_detail_last_one['str_day'])[0]
 
+    ths_stock_concept_detail_effective = ths_stock_concept_detail_effective.sort_values(by=['grade'],
+                                                                                        ascending=False)
+
+    # 最相关的概念
+    ths_stock_concept_detail_most_relative_one = ths_stock_concept_detail_effective.iloc[0:1]
+
+    if ths_stock_concept_detail_most_relative_one['concept_name'] is None:
+        df['ths_concept_most_relative_name'] = "未有"
+    else:
+        df['ths_concept_most_relative_name'] = list(ths_stock_concept_detail_last_one['concept_name'])[0]
+    if ths_stock_concept_detail_most_relative_one['concept_code'] is None:
+        df['ths_concept_most_relative_code'] = 0
+    else:
+        df['ths_concept_most_relative_code'] = list(ths_stock_concept_detail_most_relative_one['concept_code'])[0]
+
     return df
 
 
@@ -206,7 +248,7 @@ def clear_ths_concept_cache():
 
 
 def clear_one_concept_cache(concept_code):
-    get_one_symbol_all_ths_concept(concept_code).cache_clear()
+    get_one_symbol_all_ths_concept.cache_clear()
 
 
 def clear_effective_ths_concept_cache():
@@ -221,7 +263,6 @@ def get_choose_effective_ths_concept_no_cache():
 
 
 if __name__ == '__main__':
-    df_ths = get_all_ths_concept('300085')
-    while True:
-        get_choose_effective_ths_concept_no_cache()
-        print(1)
+    symbol_test = '300085'
+    company_info_df = mongodb_util.find_query_data('company_info', {"symbol": symbol_test})
+    set_ths_concept(symbol_test, company_info_df)
