@@ -44,3 +44,10 @@ ETF_QFQ_DAILY = 'etf_qfq_daily'
 # 一分钟同步失败集合
 
 ONE_MINUTE_SYNC_FAIL = 'one_minute_sync_fail'
+
+# us stock daily_k_line
+
+US_STOCK_DAILY_QFQ_K_LINE = 'us_stock_daily_qfq_k_line'
+
+# hk stock daily_k_line
+HK_STOCK_DAILY_QFQ_K_LINE = 'hk_stock_daily_qfq_k_line'
